@@ -4,6 +4,8 @@ import numpy as np
 import scipy.linalg
 import rendersettings
 import importlib
+import pytest
+
 
 def cross_py23_reload(module):
     try:
@@ -11,6 +13,7 @@ def cross_py23_reload(module):
     except NameError as e:
         importlib.reload(module)
 
+
 def test_affine_rot_90():
     am = renderapi.transform.AffineModel()
     # setup a 90 degree clockwise rotation
@@ -415,4 +418,42 @@ def test_non_linear_transform():
     xyp=lens_tform.tform(xy)
     dv = xyp-xy
     mean_disp= np.mean(np.sqrt(np.sum(dv**2,axis=1)))
-    assert((mean_disp-0.7570507)<.01)
\ No newline at end of file
+    assert((mean_disp-0.7570507)<.01)
+
+
+@pytest.mark.parametrize("transform_class,transform_json", [
+    (renderapi.transform.Transform, {
+        'className': 'some_class',
+        'dataString': '1234_some_data',
+        'id': 'myTransform',
+        'metaData': {'labels': ['my_first_label', 'my_second_label']}}),
+    (renderapi.transform.AffineModel, {
+        'className': 'mpicbg.trakem2.transform.AffineModel2D',
+        'dataString': (
+            "-0.6433267575 0.7655917209 -0.7655917209 "
+            "-0.6433267575 115071.0014383696 23073.7167961992"),
+        'id': 'myAffineModel',
+        'metaData': {'labels': ['my_first_label', 'my_second_label']}}),
+    (renderapi.transform.Polynomial2DTransform, {
+        'className': 'mpicbg.trakem2.transform.PolynomialTransform2D',
+        'dataString': (
+            '67572.7356991 0.972637082773 -0.0266434803369 '
+            '-3.08962731867E-06 3.52672451824E-06 1.36924119761E-07 '
+            '5446.85340052 0.0224047626583 0.961202608454 '
+            '-3.36753624487E-07 -8.97219078255E-07 -5.49854010072E-06'),
+        'id': 'myPolynomialModel',
+        'metaData': {'labels': ['my_first_label', 'my_second_label']}}),
+    (renderapi.transform.NonLinearCoordinateTransform,
+     dict(rendersettings.NONLINEAR_TRANSFORM_KWARGS, **{
+         'id': 'myNLCTransform',
+         'metaData': {'labels': ['my_first_label', 'my_second_label']}}))])
+def test_load_json_transforms(transform_class, transform_json):
+    tform = transform_class(json=transform_json)
+    tform_d = tform.to_dict()
+
+    # avoid comparing datastrings as strings because of rounding
+    assert (tform.transformId == tform_d['id'] == transform_json['id'])
+    assert (tform.labels == tform_d['metaData']['labels'] ==
+            transform_json['metaData']['labels'])
+    assert (tform.className == tform_d['className'] ==
+            transform_json['className'])
